===============================
Wagtail Form Blocks
===============================


.. image:: https://img.shields.io/pypi/v/wagtailsocialfeed.svg
        :target: https://pypi.python.org/pypi/wagtailsocialfeed

.. image:: https://readthedocs.org/projects/wagtailsocialfeed/badge/?version=latest
        :target: https://wagtailsocialfeed.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://travis-ci.org/LUKKIEN/wagtailsocialfeed.svg?branch=master
    :target: https://travis-ci.org/LUKKIEN/wagtailsocialfeed

A Wagtail module that provides pages and content blocks to show social media feeds


* Free software: MIT license
* Documentation: https://wagtailsocialfeed.readthedocs.io.


Features
--------

* TODO
